#include <htc.h>
/* RS232 Library for PIC16F87xA (For Now) */
/* by Matteo Merlin - last update 26/03/2007 */
/* Header File */

/* Se non definita altrove, definisce il timeout di comunicazione */
#ifndef COMM_DELAY
#define COMM_DELAY 10000 //in cicli di attesa
#endif


#define RX_PIN TRISC7
#define TX_PIN TRISC6
//------------------------------------------------------------------------------
/* Spegne e riaccende (o viceversa) un bit */
//#define TOGGLEBIT(x) x=!x; x=!x;
/* Restituisce il valore assoluto di un numero */
#define ABS(x) (x)<0 ? -(x) : (x)
/* Rinomina la macro di configurazione dei fuses */
//#define CONFIG FUSES(x) CONFIG(x)
/* Costruisce un blocco ASSERT: se y `e vero allora x */
//#define ASSERT(y,x) if(y) {x}
/* Blocco ASSERT con printf: se y `e vero allora stampa la stringa x */
//#define PRINT ASSERT(y,x) if(y) {printf(x);}
//------------------------------------------------------------------------------

int usartInit(long baud, long clock, char interr); // Abilita la USART asincrona sul PIC
void putch(unsigned char c); // Spedisce un carattere
unsigned char getch(); // Riceve un carattere (timeout: non bloccante)
//unsigned char getche(); // Legge un carattere e lo rispedisce indietro
//unsigned char kbhit(); //???
void putstr(const char *stringa); // Spedisce una stringa di caratteri
int getstr(char* buffer, int maxlen, char endchar); // Riceve una stringa di caratteri (timeout: non bloccante)
//bit commErr(void); // Gestisce e segnala la presenza di errori nella trasmissione

/* IMPLEMENTAZIONE */
#define DEBUG 0

/* Abilita la USART asincrona sul PIC */
int usartInit(long baud, long clock, char interr)
 {
 float error=0; //errore percentuale di trasmissione
 float errortmp=0;

 long temp=0;

 RX_PIN = 1; TX_PIN = 1; //Abilita i pin per la USART
 BRGH=1;             //BRGH = (baud>=9600) HIGH SPEED

      if (BRGH)     // BRGH - Baud rate generator
      {
              SPBRG = ((clock/(16*baud)))-1; //valore per trasmissione

              temp = (((SPBRG+1)*16)*baud); //denominatore
              error = (100*(float)(clock-temp))/(float)temp; //Errore di trasmissione (arr difetto)

              temp = (((SPBRG+2)*16)*baud); //Errore con arr eccesso
              errortmp = (100*(float)(clock-temp))/(float)temp;
      }
      else
      {
              SPBRG = (clock/(64*baud))-1; //valore per trasmissione

              temp = (((SPBRG+1)*64)*baud); //denominatore
              error = (100*(float)(clock-temp))/(float)temp; //Errore di trasmissione (arrdifetto)

              temp = (((SPBRG+2)*64)*baud); //Errore con arr eccesso
              errortmp = (100*(float)(clock-temp))/(float)temp;
      }

      if((ABS(errortmp)) < (ABS(error))) //Se con eccesso e' meglio
      {
              SPBRG++; //arrotonda in eccesso
              error=errortmp; //usa l�errore con eccesso
      }

      if (error>4) return (int)error; // Errore di trasmissione troppo elevato (Cambiare BaudRate o Clock)

      SYNC = 0; //SYNC = 0  modo asincrono
      SPEN=1; //SPEN = 1  Abilita RX PIN e TX PIN
      TX9=0; //TX9 = 0; //Trasmissione a 8bit
      RX9=0; //RX9 = 0; //Ricezione a 8bit

      //CREN=1; TXEN=1; //Abilita ricezione e trasmissione
      CREN=1; //CREN=1;
      TXEN=0; //TXEN=0;
      
 if(interr==0) //Configurazione Interrupt
      {RCIE=0;
       TXIE=0;} //{ RCIE = 0; TXIE = 0; } Disabilita Ricezione e Trasmissione
 else if(interr==1)
      {RCIE=1;
       TXIE=1;} //Abilita Ricezione e Trasmissione
      else if(interr==2)
            {RCIE=1;
             TXIE=0;} //Abilita Ricezione e disabilita Trasmissione
           else if(interr==3)
                  {RCIE=0;
                   TXIE=1;} //Disabilita Ricezione e abilita Trasmissione

 return (int)error;
 }

 /* Spedisce un carattere */
/*void putch(unsigned char c)
 {
 TXREG=c; //Mette nel buffer di trasmissione il carattere da spedire
 while(!TXSTA.B1)//(!TRMT)
 continue; //Non fa niente finche non e' spedito
 }*/
 
/* Riceve un carattere (no timeout: bloccante) */
 unsigned char getch() //legge un carattere da seriale
 {
 while(!RCIF)   //(!RCIF)  //aspetta finche non e' avvenuta la ricezione
        continue;
//if(commErr())                 //se ci sono errori
//        togglebit(RCSTA.B4);  //(CREN) //resetta errori


return RCREG; //restituisci il carattere letto
 }
// Riceve un carattere (timeout: non bloccante)
/*unsigned char getch()
{
 long int z;
 for(z=0; z<=COMM_DELAY; z++) //Ciclo di lettura
 {
      if(RCIF) //aspetta finche non e' avvenuta la ricezione o esaurito il timeout
      {
            if(commErr()) //se ci sono errori
            {       TOGGLEBIT(CREN); //resetta errori
                    return RCREG; //restituisciil carattere letto
            }
      }
 return 0; //restituisci 0
 }
 */
 /*
 // Legge un carattere e lo rispedisce indietro
 unsigned char getche()
 {
 unsigned char c;
 putch(c = getch()); //spedisce il carattere letto
 return c;
 }
 */

 /* Spedisce una stringa di caratteri */
 /*void putstr(const char *stringa)
 {
     do
     {
           putch(*stringa); //Spedisci il prossimo carattere di *stringa
           stringa++;
     }
     while((*stringa)!=0); //Finche la stringa non e stata spedita tutta
 }*/


 /* Riceve una stringa di caratteri (fino al terminatore) (con timeout: non bloccante)*/
 int getstr(char* buffer, int maxlen, char endchar)
 {
       int l=0; //indica la lunghezza della stringa comando
       char c=0; //indica il carattere appena letto

       do
       {
               if(c=getch()) //Se la lettura di c da esito positivo
               buffer[l++]=c; //Salva il carattere letto
       }
       while((l<maxlen) && (c!=endchar)); //resta nel ciclo finche legge caratteri, finche non ha
                                          //esaurito lo spazio o non ha incontrato il carattere di END
       return l; //ritorna la lunghezza della stringa letta
 }


 //Gestisce e segnala la presenza di errori nella trasmissione
/* bit commErr(void)
 {
    if(!OERR && !FERR) //Se non ci sono errori
    {
         return 0;
    }
    else
    {
         #if DEBUG
         if (OERR) putstr("OVERRUN ERROR\n\r"); //Errore di OVERRUN
         if (FERR) putstr("FRAME ERROR\n\r"); //Errore di FRAME
         #endif

         return 1;
     }
}
*/
