package game;

public class Retta {

	protected Punto p0;
	protected double m;

	/** Costruttore nullo */
	public Retta() {
		// nulla
	}

	// Overloading del costruttore nullo
	public Retta(Punto p0, double m) {
		this.p0 = p0;
		this.m = m;
	}

	/**
	 * Overloading del costruttore precedente: individua la rella passante per
	 * due punti
	 */
	public Retta(Punto p1, Punto p2) {
		this(p1, (p2.y - p1.y) / (p2.x - p1.x));
	}

	/**
	 * Overloading del costruttore: individua la retta di coefficiente angolare
	 * c e termine noto t
	 */
	public Retta(double c, double t) {
		this(new Punto(0, t), c);
	}

    public void setValori(Punto p1, Punto p2){
        this.p0=p1;
        this.m=(p2.y - p1.y) / (p2.x - p1.x);
    }

	/** Stabilisce se il punto p appartiene alla retta */
	public boolean appartiene(Punto p) {
		return (p.y - p0.y == m * (p.x - p0.x));
	}

	/** Verifica se due rette sono uguali */
	public boolean equals(Retta r) {
		return (this.appartiene(r.p0) && this.parallela(r));
	}

	/** Stabilisce il parallelismo tra rette */
	public boolean parallela(Retta r) {
		return (r.m == this.m);
	}

	/** Restituisce il coefficiente angolare della retta */
	public double coefficienteAngolare() {
		return m;
	}

	/** Restituisce il termine noto */
	public double termineNoto() {
		return p0.y - m * p0.x;
	}

	/** Trova il punto di intersezione tra due rette se esiste */
	public Punto intersezione(Retta r) {
		if (!this.parallela(r)) {
			double x = (this.termineNoto() - r.termineNoto())
					/ (r.coefficienteAngolare() - this.coefficienteAngolare());
			double y = r.coefficienteAngolare() * x + r.termineNoto();
			return new Punto(x, y);
		} else
			return null;
	}

	/** Stabilisce se la retta � parallela all'asse delle X */
	public boolean isParallelaAsseX() {
		return (m == 0);
	}

	/** Stabilisce se la retta � parallela all'asse delle Y */
	public boolean isParallelaAsseY() {
		return (m == Double.POSITIVE_INFINITY || m == Double.NEGATIVE_INFINITY);
	}

	/** Punto di intersezione con l'asse delle X, se esiste */
	public Punto intersezioneAsseX() {
		if (!this.isParallelaAsseX())
			return new Punto(p0.x - p0.y / m, 0);
		else
			return null;
	}

	/** Punto di intersezione con l'asse delle Y, se esiste */
	public Punto intersezioneAsseY() {
		if (!this.isParallelaAsseY())
			return new Punto(0, p0.y - p0.x * m);
		else
			return null;
	}
} // fine classe Retta

